// ExecuteCommandDlg.h
// (c) 2003 exeal

#ifndef _EXECUTE_COMMAND_DLG_H_
#define _EXECUTE_COMMAND_DLG_H_

#include "..\Manah\Dialog.h"
#include "..\Manah\DosCommand.h"
using Manah::Windows::Controls::CDialog;
using Manah::Windows::CDosCommand;


namespace Alpha {

class CAlphaApp;

// CExecuteCommandDlg class definition
/////////////////////////////////////////////////////////////////////////////

///	[R}h̎s] _CAO
class CExecuteCommandDlg :
		public CDialog,
		virtual public CDosCommand::ICommandEvent {
	// f[^o
private:
	CAlphaApp*	m_pApplication;
	wstring		m_strCmdLine;
	CDosCommand	m_oDosCommand;
	bool		m_bExecuting;	// R}hs
public:
	list<wstring>	m_listCommands;
	bool			m_bHijackConsole;
	bool			m_bUseUnicode;
	
	// RXgN^
public:
	CExecuteCommandDlg(CAlphaApp* pApplication);

	// \bh
public:
	// CDosCommand::ICommandEvent C^[tFCX
	virtual void	OnExit(CDosCommand::ExecuteStatus es);
	virtual void	OnReceiveOutput(const string& strOutput);

	// bZ[Wnh
protected:
	virtual void	OnClose();												// WM_CLOSE
	virtual bool	OnCommand(WORD wID, WORD wNotifyCode, HWND hwndCtrl);	// WM_COMMAND
	virtual bool	OnInitDialog(HWND hwndFocus, LPARAM lInitParam);		// WM_INITDIALOG
	virtual void	OnCancel();												// IDCANCEL
	virtual void	OnOK();													// IDOK
};

}

#endif /* _EXECUTE_COMMAND_DLG_H_ */

/* [EOF] */